@@ -7,7 +7,7 @@ from gridsource.validation import ValidatorMixin
 
 __author__ = """Nicolas Cordier"""
 __email__ = "nicolas.cordier@numeric-gmbh.ch"
-__version__ = "0.44.0"
+__version__ = "0.45.0"
 
 
 class _Base:
@@ -25,6 +25,12 @@ class _Base:
             raise AttributeError(f"`tabname` should be one of {set(self._data.keys())}")
         return getattr(self, attr)[tabname]
 
+    def tabs(self, ordered=False):
+        """return contained tabs"""
+        if not ordered:
+            return set(getattr(self, "_data").keys())
+        return list(getattr(self, "_data").keys())
+
 
 class Data(_Base, IOMixin, ValidatorMixin):
     pass
