@@ -657,16 +657,21 @@ def dump_xlsx_template(schemas, output, tabs=(), excluded_tabs=None):
     if excluded_tabs:
         schemas = {k: v for k, v in schemas.items() if k not in excluded_tabs}
     # -------------------------------------------------------------------------
-    # check implicit tabs xcalls
+    # check implicit tabs xcalls 
     tabs = list(tabs)
+    _additional_tabs = []
     for tabname, schema in schemas.items():
         for referencing_col, (
             referenced_tab,
             referenced_col,
+            check_func,
         ) in schema.xcalling.items():
             if referenced_tab not in tabs:
                 logging.warning(f"add referenced {referenced_tab}")
+                _additional_tabs.append(referenced_tab)
                 tabs.append(referenced_tab)
+    # update filtered schema with additional_tabs
+    schemas.update({k: v for k, v in data._schemas.items() if k in _additional_tabs})
     data._schemas = schemas
     cols = data.dump_template()  # get columns and attributes
     cols = {k: cols[k] for k in tabs}  # reorder as required by `tabs` order
