@@ -18,6 +18,8 @@ import pint_pandas as pintpandas
 import pkg_resources
 import simplejson as json
 import yaml
+import tempfile
+import shutil
 
 ureg = pint.UnitRegistry()
 UNIQUENESS_SEP = " & "
@@ -26,7 +28,7 @@ UNIQUENESS_SEP = " & "
 def yamlcat(*files):
     """concat YAML files and returns a StringIO object
 
-    files is an iterable of posibly:
+    files is an iterable of possibly:
       * StringIO object
       * strings:
         - YAML content (shall begin with "---")
@@ -103,7 +105,15 @@ def load_yaml(*files, clean=True, debug=False):
     True
     """
     src = yamlcat(*files)
-    specs = yaml.load(src, Loader=yaml.FullLoader)
+    try:
+        specs = yaml.load(src, Loader=yaml.FullLoader)
+    except yaml.scanner.ScannerError as exc:
+        _, path = tempfile.mkstemp(suffix=".yaml")
+        src.seek(0)
+        with open(path, "w") as fp:
+            shutil.copyfileobj(src, fp)
+        logging.critical(f"cannot parse {fp.name} {exc}")
+        raise
     if clean:
         # clean keys beginning with "_" if required
         specs = {k: v for k, v in specs.items() if not k.startswith("_")}
@@ -381,6 +391,7 @@ class DataFrameSchematizer:
         # ---------------------------------------------------------
         if len(types) > 1:
             items = {"anyOf": [{"type": typ} for typ in types]}
+            kwargs.pop("type", None)
         else:
             items = {"type": types[0]}
         items.update(kwargs)
