@@ -3,6 +3,8 @@ import tempfile
 from io import StringIO
 from pathlib import Path
 import shutil
+import subprocess
+import shlex
 
 import pytest
 
@@ -36,9 +38,15 @@ def test_00(datadir):
     )
     # with tempfile.TemporaryDirectory() as tmpdirname:
     #     ad = VDataAutodoc(ivdata, target_dir=Path(tmpdirname)/"DOC")
-    ad = VDataAutodoc(ivdata, target_dir=Path("~/DOC").expanduser())
+    target_dir = Path(tempfile.mkdtemp()) / "test_autodoc"
+    ad = VDataAutodoc(ivdata, target_dir=target_dir)
     try:
-        ad.create(project_name="totor", author="me", version="1.2", exist_ok=False)
+        ad.create(
+            project_name="totor",
+            author="me",
+            version="1.2",
+            exist_ok=False,
+        )
     except FileExistsError:
         pass
     ad.dump_data(
@@ -50,3 +58,10 @@ def test_00(datadir):
             "maximum": "max",
         },
     )
+    # -------------------------------------------------------------------------
+    # check make html works
+    prev_cwd = os.getcwd()
+    os.chdir(target_dir)
+    ret = subprocess.run(["/usr/bin/make", "html"], shell=True)
+    assert ret.returncode == 0
+    os.chdir(prev_cwd)
