@@ -683,6 +683,23 @@ def test_IVData_06_units(datadir):
     )
     diff = l9_quantity - l9_quantity_exp
     assert abs(diff.magnitude) < 1e-5
+    # -------------------------------------------------------------------------
+    # to_configobj
+    co = data_imp.to_configobj()
+    new_data = IVData()
+    new_data.read_configobj(co)
+    new_data.read_schema(
+        os.path.join(indir, "test_04_IMP.yaml"),
+        os.path.join(indir, "test_04_data.yaml"),
+    )
+    new_data.validate()
+    assert new_data.getunits("pressure", key="test_p_bar") == "psi"
+    for tabname in data_imp._data:
+        df_imp = data_imp.convert_to(tabname)  # .pint.to_base_units()
+        df_new_data = new_data.convert_to(tabname)  # .pint.to_base_units()
+        exp = df_imp.pint.dequantify()
+        act = df_new_data.pint.dequantify()
+        assert pd.testing.assert_frame_equal(exp, act) is None
 
 
 def test_IVData_07_failing_units(datadir):
@@ -796,7 +813,7 @@ def test_IVData_08_multi_cols_uniqueness(datadir):
 
 
 def test_IVData_09_must_exist_in(datadir):
-    """check must exist req"""
+    """check 'must exist' and 'must not exist' req"""
     indir, outdir = datadir
     data = IVData()
     data.read_excel(os.path.join(indir, "test_06_must_exist_in.xlsx"))
@@ -811,6 +828,7 @@ def test_IVData_09_must_exist_in(datadir):
             ],
         },
         "colors": {
+            ("id", 2): ["'value `1` unexpectidely found in `beam_def::id`"],
             ("id", 4): ["'tata' is not of type 'integer'"],
             ("name", 4): ["5 is not of type 'string'"],
         },
